summaryrefslogtreecommitdiffstats
path: root/google_apis
diff options
context:
space:
mode:
authorfukino@chromium.org <fukino@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-07-14 13:58:22 +0000
committerfukino@chromium.org <fukino@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-07-14 13:58:22 +0000
commit51ed7bd425d4b42e8bb6b5e1db0fe260289f99d7 (patch)
tree90a61d7350b5bf1fe48b3e06bb27aa9de8e0c36d /google_apis
parent15c793916c8621c6340da01268a220c501d5ecc3 (diff)
downloadchromium_src-51ed7bd425d4b42e8bb6b5e1db0fe260289f99d7.zip
chromium_src-51ed7bd425d4b42e8bb6b5e1db0fe260289f99d7.tar.gz
chromium_src-51ed7bd425d4b42e8bb6b5e1db0fe260289f99d7.tar.bz2
Get rid of DriveEntryKind.
Basically DriveEntryKind is used for clasifying files into one of {Folder, Hosted document, Normal file}. We can classify them without DriveEntryKind by using FileResource::IsDirectory() and their mime type. Utility functions for clasification are now indepenent with ResourceEntry, and placed in drive_api_util.h. ResourceEntryKind is defined to provide users of ResourceEntry (e.g. sync file system) with similar accessor to file kind. BUG=357038 TBR=rogerta@chromium.org for one line removal in .gyp file and .gn file. TEST=run google_apis_unittests and unit_tests Review URL: https://codereview.chromium.org/384543004 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@282941 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'google_apis')
-rw-r--r--google_apis/BUILD.gn1
-rw-r--r--google_apis/drive/drive_entry_kinds.h40
-rw-r--r--google_apis/drive/gdata_wapi_parser.cc116
-rw-r--r--google_apis/drive/gdata_wapi_parser.h67
-rw-r--r--google_apis/drive/gdata_wapi_parser_unittest.cc104
-rw-r--r--google_apis/google_apis.gyp1
6 files changed, 28 insertions, 301 deletions
diff --git a/google_apis/BUILD.gn b/google_apis/BUILD.gn
index f5d5a2e..33ecc00 100644
--- a/google_apis/BUILD.gn
+++ b/google_apis/BUILD.gn
@@ -154,7 +154,6 @@ source_set("google_apis") {
"drive/drive_api_url_generator.cc",
"drive/drive_api_url_generator.h",
"drive/drive_common_callbacks.h",
- "drive/drive_entry_kinds.h",
"drive/gdata_errorcode.cc",
"drive/gdata_errorcode.h",
"drive/gdata_wapi_requests.cc",
diff --git a/google_apis/drive/drive_entry_kinds.h b/google_apis/drive/drive_entry_kinds.h
deleted file mode 100644
index 27e0f69..0000000
--- a/google_apis/drive/drive_entry_kinds.h
+++ /dev/null
@@ -1,40 +0,0 @@
-// Copyright (c) 2012 The Chromium Authors. All rights reserved.
-// Use of this source code is governed by a BSD-style license that can be
-// found in the LICENSE file.
-
-#ifndef GOOGLE_APIS_DRIVE_DRIVE_ENTRY_KINDS_H_
-#define GOOGLE_APIS_DRIVE_DRIVE_ENTRY_KINDS_H_
-
-namespace google_apis {
-
-// DriveEntryKind specifies the kind of a Drive entry.
-//
-// kEntryKindMap in gdata_wapi_parser.cc should also be updated if you modify
-// DriveEntryKind. The compiler will catch if they are not in sync.
-enum DriveEntryKind {
- ENTRY_KIND_UNKNOWN,
- // Special entries.
- ENTRY_KIND_ITEM,
- ENTRY_KIND_SITE,
- // Hosted Google document.
- ENTRY_KIND_DOCUMENT,
- ENTRY_KIND_SPREADSHEET,
- ENTRY_KIND_PRESENTATION,
- ENTRY_KIND_DRAWING,
- ENTRY_KIND_TABLE,
- ENTRY_KIND_FORM,
- // Hosted external application document.
- ENTRY_KIND_EXTERNAL_APP,
- // Folders; collections.
- ENTRY_KIND_FOLDER,
- // Regular files.
- ENTRY_KIND_FILE,
- ENTRY_KIND_PDF,
-
- // This should be the last item.
- ENTRY_KIND_MAX_VALUE,
-};
-
-} // namespace google_apis
-
-#endif // GOOGLE_APIS_DRIVE_DRIVE_ENTRY_KINDS_H_
diff --git a/google_apis/drive/gdata_wapi_parser.cc b/google_apis/drive/gdata_wapi_parser.cc
index 9c50e5a..83beacc 100644
--- a/google_apis/drive/gdata_wapi_parser.cc
+++ b/google_apis/drive/gdata_wapi_parser.cc
@@ -72,30 +72,6 @@ const char kUpdatedField[] = "updated.$t";
const char kOpenWithPrefix[] = "http://schemas.google.com/docs/2007#open-with-";
const size_t kOpenWithPrefixSize = arraysize(kOpenWithPrefix) - 1;
-struct EntryKindMap {
- DriveEntryKind kind;
- const char* entry;
- const char* extension;
-};
-
-const EntryKindMap kEntryKindMap[] = {
- { ENTRY_KIND_UNKNOWN, "unknown", NULL},
- { ENTRY_KIND_ITEM, "item", NULL},
- { ENTRY_KIND_DOCUMENT, "document", ".gdoc"},
- { ENTRY_KIND_SPREADSHEET, "spreadsheet", ".gsheet"},
- { ENTRY_KIND_PRESENTATION, "presentation", ".gslides" },
- { ENTRY_KIND_DRAWING, "drawing", ".gdraw"},
- { ENTRY_KIND_TABLE, "table", ".gtable"},
- { ENTRY_KIND_FORM, "form", ".gform"},
- { ENTRY_KIND_EXTERNAL_APP, "externalapp", ".glink"},
- { ENTRY_KIND_SITE, "site", NULL},
- { ENTRY_KIND_FOLDER, "folder", NULL},
- { ENTRY_KIND_FILE, "file", NULL},
- { ENTRY_KIND_PDF, "pdf", NULL},
-};
-COMPILE_ASSERT(arraysize(kEntryKindMap) == ENTRY_KIND_MAX_VALUE,
- EntryKindMap_and_DriveEntryKind_are_not_in_sync);
-
struct LinkTypeMap {
Link::LinkType type;
const char* rel;
@@ -439,42 +415,7 @@ void ResourceEntry::RegisterJSONConverter(
}
// static
-std::string ResourceEntry::GetHostedDocumentExtension(DriveEntryKind kind) {
- for (size_t i = 0; i < arraysize(kEntryKindMap); i++) {
- if (kEntryKindMap[i].kind == kind) {
- if (kEntryKindMap[i].extension)
- return std::string(kEntryKindMap[i].extension);
- else
- return std::string();
- }
- }
- return std::string();
-}
-
-// static
-DriveEntryKind ResourceEntry::GetEntryKindFromExtension(
- const std::string& extension) {
- for (size_t i = 0; i < arraysize(kEntryKindMap); ++i) {
- const char* document_extension = kEntryKindMap[i].extension;
- if (document_extension && extension == document_extension)
- return kEntryKindMap[i].kind;
- }
- return ENTRY_KIND_UNKNOWN;
-}
-
-// static
-int ResourceEntry::ClassifyEntryKindByFileExtension(
- const base::FilePath& file_path) {
-#if defined(OS_WIN)
- std::string file_extension = base::WideToUTF8(file_path.Extension());
-#else
- std::string file_extension = file_path.Extension();
-#endif
- return ClassifyEntryKind(GetEntryKindFromExtension(file_extension));
-}
-
-// static
-DriveEntryKind ResourceEntry::GetEntryKindFromTerm(
+ResourceEntry::ResourceEntryKind ResourceEntry::GetEntryKindFromTerm(
const std::string& term) {
if (!StartsWithASCII(term, kTermPrefix, false)) {
DVLOG(1) << "Unexpected term prefix term " << term;
@@ -482,60 +423,15 @@ DriveEntryKind ResourceEntry::GetEntryKindFromTerm(
}
std::string type = term.substr(strlen(kTermPrefix));
- for (size_t i = 0; i < arraysize(kEntryKindMap); i++) {
- if (type == kEntryKindMap[i].entry)
- return kEntryKindMap[i].kind;
- }
+ if (type == "folder")
+ return ENTRY_KIND_FOLDER;
+ if (type == "file" || type == "pdf")
+ return ENTRY_KIND_FILE;
+
DVLOG(1) << "Unknown entry type for term " << term << ", type " << type;
return ENTRY_KIND_UNKNOWN;
}
-// static
-int ResourceEntry::ClassifyEntryKind(DriveEntryKind kind) {
- int classes = 0;
-
- // All DriveEntryKind members are listed here, so the compiler catches if a
- // newly added member is missing here.
- switch (kind) {
- case ENTRY_KIND_UNKNOWN:
- // Special entries.
- case ENTRY_KIND_ITEM:
- case ENTRY_KIND_SITE:
- break;
-
- // Hosted Google document.
- case ENTRY_KIND_DOCUMENT:
- case ENTRY_KIND_SPREADSHEET:
- case ENTRY_KIND_PRESENTATION:
- case ENTRY_KIND_DRAWING:
- case ENTRY_KIND_TABLE:
- case ENTRY_KIND_FORM:
- classes = KIND_OF_GOOGLE_DOCUMENT | KIND_OF_HOSTED_DOCUMENT;
- break;
-
- // Hosted external application document.
- case ENTRY_KIND_EXTERNAL_APP:
- classes = KIND_OF_EXTERNAL_DOCUMENT | KIND_OF_HOSTED_DOCUMENT;
- break;
-
- // Folders, collections.
- case ENTRY_KIND_FOLDER:
- classes = KIND_OF_FOLDER;
- break;
-
- // Regular files.
- case ENTRY_KIND_FILE:
- case ENTRY_KIND_PDF:
- classes = KIND_OF_FILE;
- break;
-
- case ENTRY_KIND_MAX_VALUE:
- NOTREACHED();
- }
-
- return classes;
-}
-
void ResourceEntry::FillRemainingFields() {
// Set |kind_| and |labels_| based on the |categories_| in the class.
// JSONValueConverter does not have the ability to catch an element in a list
diff --git a/google_apis/drive/gdata_wapi_parser_unittest.cc b/google_apis/drive/gdata_wapi_parser_unittest.cc
index 6655aed..8f14d92 100644
--- a/google_apis/drive/gdata_wapi_parser_unittest.cc
+++ b/google_apis/drive/gdata_wapi_parser_unittest.cc
@@ -60,7 +60,7 @@ TEST(GDataWAPIParserTest, ResourceListJsonParser) {
// Check a folder entry.
const ResourceEntry* folder_entry = feed->entries()[0];
ASSERT_TRUE(folder_entry);
- EXPECT_EQ(ENTRY_KIND_FOLDER, folder_entry->kind());
+ EXPECT_EQ(ResourceEntry::ENTRY_KIND_FOLDER, folder_entry->kind());
EXPECT_EQ("\"HhMOFgcNHSt7ImBr\"", folder_entry->etag());
EXPECT_EQ("folder:sub_sub_directory_folder_id", folder_entry->resource_id());
EXPECT_EQ("https://1_folder_id", folder_entry->id());
@@ -102,7 +102,7 @@ TEST(GDataWAPIParserTest, ResourceListJsonParser) {
// Check a file entry.
const ResourceEntry* file_entry = feed->entries()[1];
ASSERT_TRUE(file_entry);
- EXPECT_EQ(ENTRY_KIND_FILE, file_entry->kind());
+ EXPECT_EQ(ResourceEntry::ENTRY_KIND_FILE, file_entry->kind());
EXPECT_EQ("filename.m4a", file_entry->filename());
EXPECT_EQ("sugg_file_name.m4a", file_entry->suggested_filename());
EXPECT_EQ("3b4382ebefec6e743578c76bbd0575ce", file_entry->file_md5());
@@ -131,18 +131,16 @@ TEST(GDataWAPIParserTest, ResourceListJsonParser) {
// Check a file entry.
const ResourceEntry* resource_entry = feed->entries()[2];
ASSERT_TRUE(resource_entry);
- EXPECT_EQ(ENTRY_KIND_DOCUMENT, resource_entry->kind());
- EXPECT_TRUE(resource_entry->is_hosted_document());
- EXPECT_TRUE(resource_entry->is_google_document());
- EXPECT_FALSE(resource_entry->is_external_document());
+ // Hosted documents are treated as unknown kind so that sync file system
+ // doesn't assume them as neither folders nor normal files.
+ EXPECT_EQ(ResourceEntry::ENTRY_KIND_UNKNOWN, resource_entry->kind());
// Check an external document entry.
const ResourceEntry* app_entry = feed->entries()[3];
ASSERT_TRUE(app_entry);
- EXPECT_EQ(ENTRY_KIND_EXTERNAL_APP, app_entry->kind());
- EXPECT_TRUE(app_entry->is_hosted_document());
- EXPECT_TRUE(app_entry->is_external_document());
- EXPECT_FALSE(app_entry->is_google_document());
+ // Hosted documents are treated as unknown kind so that sync file system
+ // doesn't assume them as neither folders nor normal files.
+ EXPECT_EQ(ResourceEntry::ENTRY_KIND_UNKNOWN, app_entry->kind());
}
@@ -156,7 +154,7 @@ TEST(GDataWAPIParserTest, ResourceEntryJsonParser) {
scoped_ptr<ResourceEntry> entry(ResourceEntry::ExtractAndParse(*document));
ASSERT_TRUE(entry.get());
- EXPECT_EQ(ENTRY_KIND_FILE, entry->kind());
+ EXPECT_EQ(ResourceEntry::ENTRY_KIND_FILE, entry->kind());
EXPECT_EQ("\"HhMOFgxXHit7ImBr\"", entry->etag());
EXPECT_EQ("file:2_file_resource_id", entry->resource_id());
EXPECT_EQ("2_file_id", entry->id());
@@ -222,7 +220,7 @@ TEST(GDataWAPIParserTest, ResourceEntryJsonParser) {
EXPECT_EQ("", entry1_unknown_link->app_id());
// Check a file properties.
- EXPECT_EQ(ENTRY_KIND_FILE, entry->kind());
+ EXPECT_EQ(ResourceEntry::ENTRY_KIND_FILE, entry->kind());
EXPECT_EQ("File 1.mp3", entry->filename());
EXPECT_EQ("File 1.mp3", entry->suggested_filename());
EXPECT_EQ("3b4382ebefec6e743578c76bbd0575ce", entry->file_md5());
@@ -235,86 +233,4 @@ TEST(GDataWAPIParserTest, ResourceEntryJsonParser) {
EXPECT_EQ(-1, entry->image_rotation());
}
-TEST(GDataWAPIParserTest, ClassifyEntryKindByFileExtension) {
- EXPECT_EQ(
- ResourceEntry::KIND_OF_GOOGLE_DOCUMENT |
- ResourceEntry::KIND_OF_HOSTED_DOCUMENT,
- ResourceEntry::ClassifyEntryKindByFileExtension(
- base::FilePath(FILE_PATH_LITERAL("Test.gdoc"))));
- EXPECT_EQ(
- ResourceEntry::KIND_OF_GOOGLE_DOCUMENT |
- ResourceEntry::KIND_OF_HOSTED_DOCUMENT,
- ResourceEntry::ClassifyEntryKindByFileExtension(
- base::FilePath(FILE_PATH_LITERAL("Test.gsheet"))));
- EXPECT_EQ(
- ResourceEntry::KIND_OF_GOOGLE_DOCUMENT |
- ResourceEntry::KIND_OF_HOSTED_DOCUMENT,
- ResourceEntry::ClassifyEntryKindByFileExtension(
- base::FilePath(FILE_PATH_LITERAL("Test.gslides"))));
- EXPECT_EQ(
- ResourceEntry::KIND_OF_GOOGLE_DOCUMENT |
- ResourceEntry::KIND_OF_HOSTED_DOCUMENT,
- ResourceEntry::ClassifyEntryKindByFileExtension(
- base::FilePath(FILE_PATH_LITERAL("Test.gdraw"))));
- EXPECT_EQ(
- ResourceEntry::KIND_OF_GOOGLE_DOCUMENT |
- ResourceEntry::KIND_OF_HOSTED_DOCUMENT,
- ResourceEntry::ClassifyEntryKindByFileExtension(
- base::FilePath(FILE_PATH_LITERAL("Test.gtable"))));
- EXPECT_EQ(
- ResourceEntry::KIND_OF_EXTERNAL_DOCUMENT |
- ResourceEntry::KIND_OF_HOSTED_DOCUMENT,
- ResourceEntry::ClassifyEntryKindByFileExtension(
- base::FilePath(FILE_PATH_LITERAL("Test.glink"))));
- EXPECT_EQ(
- ResourceEntry::KIND_OF_NONE,
- ResourceEntry::ClassifyEntryKindByFileExtension(
- base::FilePath(FILE_PATH_LITERAL("Test.tar.gz"))));
- EXPECT_EQ(
- ResourceEntry::KIND_OF_NONE,
- ResourceEntry::ClassifyEntryKindByFileExtension(
- base::FilePath(FILE_PATH_LITERAL("Test.txt"))));
- EXPECT_EQ(
- ResourceEntry::KIND_OF_NONE,
- ResourceEntry::ClassifyEntryKindByFileExtension(
- base::FilePath(FILE_PATH_LITERAL("Test"))));
- EXPECT_EQ(
- ResourceEntry::KIND_OF_NONE,
- ResourceEntry::ClassifyEntryKindByFileExtension(
- base::FilePath()));
-}
-
-TEST(GDataWAPIParserTest, ResourceEntryClassifyEntryKind) {
- EXPECT_EQ(ResourceEntry::KIND_OF_NONE,
- ResourceEntry::ClassifyEntryKind(ENTRY_KIND_UNKNOWN));
- EXPECT_EQ(ResourceEntry::KIND_OF_NONE,
- ResourceEntry::ClassifyEntryKind(ENTRY_KIND_ITEM));
- EXPECT_EQ(ResourceEntry::KIND_OF_NONE,
- ResourceEntry::ClassifyEntryKind(ENTRY_KIND_SITE));
- EXPECT_EQ(ResourceEntry::KIND_OF_GOOGLE_DOCUMENT |
- ResourceEntry::KIND_OF_HOSTED_DOCUMENT,
- ResourceEntry::ClassifyEntryKind(ENTRY_KIND_DOCUMENT));
- EXPECT_EQ(ResourceEntry::KIND_OF_GOOGLE_DOCUMENT |
- ResourceEntry::KIND_OF_HOSTED_DOCUMENT,
- ResourceEntry::ClassifyEntryKind(ENTRY_KIND_SPREADSHEET));
- EXPECT_EQ(ResourceEntry::KIND_OF_GOOGLE_DOCUMENT |
- ResourceEntry::KIND_OF_HOSTED_DOCUMENT,
- ResourceEntry::ClassifyEntryKind(ENTRY_KIND_PRESENTATION));
- EXPECT_EQ(ResourceEntry::KIND_OF_GOOGLE_DOCUMENT |
- ResourceEntry::KIND_OF_HOSTED_DOCUMENT,
- ResourceEntry::ClassifyEntryKind(ENTRY_KIND_DRAWING));
- EXPECT_EQ(ResourceEntry::KIND_OF_GOOGLE_DOCUMENT |
- ResourceEntry::KIND_OF_HOSTED_DOCUMENT,
- ResourceEntry::ClassifyEntryKind(ENTRY_KIND_TABLE));
- EXPECT_EQ(ResourceEntry::KIND_OF_EXTERNAL_DOCUMENT |
- ResourceEntry::KIND_OF_HOSTED_DOCUMENT,
- ResourceEntry::ClassifyEntryKind(ENTRY_KIND_EXTERNAL_APP));
- EXPECT_EQ(ResourceEntry::KIND_OF_FOLDER,
- ResourceEntry::ClassifyEntryKind(ENTRY_KIND_FOLDER));
- EXPECT_EQ(ResourceEntry::KIND_OF_FILE,
- ResourceEntry::ClassifyEntryKind(ENTRY_KIND_FILE));
- EXPECT_EQ(ResourceEntry::KIND_OF_FILE,
- ResourceEntry::ClassifyEntryKind(ENTRY_KIND_PDF));
-}
-
} // namespace google_apis
diff --git a/google_apis/google_apis.gyp b/google_apis/google_apis.gyp
index 1d2642f..fd3a525 100644
--- a/google_apis/google_apis.gyp
+++ b/google_apis/google_apis.gyp
@@ -65,7 +65,6 @@
'drive/drive_api_url_generator.cc',
'drive/drive_api_url_generator.h',
'drive/drive_common_callbacks.h',
- 'drive/drive_entry_kinds.h',
'drive/gdata_errorcode.cc',
'drive/gdata_errorcode.h',
'drive/gdata_wapi_requests.cc',
diff --git a/google_apis/drive/gdata_wapi_parser.h b/google_apis/drive/gdata_wapi_parser.h
index 1081dbc..f7bce81 100644
--- a/google_apis/drive/gdata_wapi_parser.h
+++ b/google_apis/drive/gdata_wapi_parser.h
@@ -14,7 +14,6 @@
#include "base/memory/scoped_vector.h"
#include "base/strings/string_piece.h"
#include "base/time/time.h"
-#include "google_apis/drive/drive_entry_kinds.h"
#include "url/gurl.h"
namespace base {
@@ -312,6 +311,11 @@ class CommonMetadata {
// refers to a file and a directory.
class ResourceEntry : public CommonMetadata {
public:
+ enum ResourceEntryKind {
+ ENTRY_KIND_UNKNOWN,
+ ENTRY_KIND_FOLDER,
+ ENTRY_KIND_FILE
+ };
ResourceEntry();
virtual ~ResourceEntry();
@@ -360,7 +364,7 @@ class ResourceEntry : public CommonMetadata {
// The URL is currently not used.
const std::string& id() const { return id_; }
- DriveEntryKind kind() const { return kind_; }
+ ResourceEntryKind kind() const { return kind_; }
const std::string& title() const { return title_; }
base::Time published_time() const { return published_time_; }
base::Time last_viewed_time() const { return last_viewed_time_; }
@@ -418,65 +422,20 @@ class ResourceEntry : public CommonMetadata {
// unknown entry kind.
std::string GetEntryKindText() const;
- // Returns preferred file extension for hosted documents. If entry is not
- // a hosted document, this call returns an empty string.
- static std::string GetHostedDocumentExtension(DriveEntryKind kind);
-
- // True if resource entry is remotely hosted.
- bool is_hosted_document() const {
- return (ClassifyEntryKind(kind_) & KIND_OF_HOSTED_DOCUMENT) > 0;
- }
- // True if resource entry hosted by Google Documents.
- bool is_google_document() const {
- return (ClassifyEntryKind(kind_) & KIND_OF_GOOGLE_DOCUMENT) > 0;
- }
- // True if resource entry is hosted by an external application.
- bool is_external_document() const {
- return (ClassifyEntryKind(kind_) & KIND_OF_EXTERNAL_DOCUMENT) > 0;
- }
// True if resource entry is a folder (collection).
bool is_folder() const {
- return (ClassifyEntryKind(kind_) & KIND_OF_FOLDER) > 0;
+ return kind_ == ENTRY_KIND_FOLDER;
}
// True if resource entry is regular file.
bool is_file() const {
- return (ClassifyEntryKind(kind_) & KIND_OF_FILE) > 0;
- }
- // True if resource entry can't be mapped to the file system.
- bool is_special() const {
- return !is_file() && !is_folder() && !is_hosted_document();
+ return kind_ == ENTRY_KIND_FILE;
}
- // The following constructs are exposed for unit tests.
-
- // Classes of EntryKind. Used for ClassifyEntryKind().
- enum EntryKindClass {
- KIND_OF_NONE = 0,
- KIND_OF_HOSTED_DOCUMENT = 1,
- KIND_OF_GOOGLE_DOCUMENT = 1 << 1,
- KIND_OF_EXTERNAL_DOCUMENT = 1 << 2,
- KIND_OF_FOLDER = 1 << 3,
- KIND_OF_FILE = 1 << 4,
- };
-
- // Returns the kind enum corresponding to the extension in form ".xxx".
- static DriveEntryKind GetEntryKindFromExtension(const std::string& extension);
-
- // Classifies the EntryKind. The returned value is a bitmask of
- // EntryKindClass. For example, DOCUMENT is classified as
- // KIND_OF_HOSTED_DOCUMENT and KIND_OF_GOOGLE_DOCUMENT, hence the returned
- // value is KIND_OF_HOSTED_DOCUMENT | KIND_OF_GOOGLE_DOCUMENT.
- static int ClassifyEntryKind(DriveEntryKind kind);
-
- // Classifies the EntryKind by the file extension of specific path. The
- // returned value is a bitmask of EntryKindClass. See also ClassifyEntryKind.
- static int ClassifyEntryKindByFileExtension(const base::FilePath& file);
-
void set_resource_id(const std::string& resource_id) {
resource_id_ = resource_id;
}
void set_id(const std::string& id) { id_ = id; }
- void set_kind(DriveEntryKind kind) { kind_ = kind; }
+ void set_kind(ResourceEntryKind kind) { kind_ = kind; }
void set_title(const std::string& title) { title_ = title; }
void set_published_time(const base::Time& published_time) {
published_time_ = published_time;
@@ -521,14 +480,12 @@ class ResourceEntry : public CommonMetadata {
friend class ResourceList;
friend class ResumeUploadRequest;
- // Converts categories.term into DriveEntryKind enum.
- static DriveEntryKind GetEntryKindFromTerm(const std::string& term);
- // Converts |kind| into its text identifier equivalent.
- static const char* GetEntryKindDescription(DriveEntryKind kind);
+ // Converts categories.term into ResourceEntryKind enum.
+ static ResourceEntryKind GetEntryKindFromTerm(const std::string& term);
std::string resource_id_;
std::string id_;
- DriveEntryKind kind_;
+ ResourceEntryKind kind_;
std::string title_;
base::Time published_time_;
// Last viewed value may be unreliable. See: crbug.com/152628.